"""MQTT HTTP Proxy Server."""
from flask import Flask, request
from flask_httpauth import HTTPBasicAuth
from werkzeug.security import check_password_hash
import paho.mqtt.client as mq
from waitress import serve

from flask_mqtt_proxy.config import (
    HTTP_PASS,
    HTTP_USER,
    MQTT_HOST,
    MQTT_PASS,
    MQTT_PORT,
    MQTT_USER,
)


app = Flask(__name__)
auth = HTTPBasicAuth()


@auth.verify_password
def verify_password(username: str, password: str) -> str | None:
    """Verify the basic auth username and password."""
    if username == HTTP_USER and check_password_hash(HTTP_PASS, password):
        return username
    return None


@app.route("/<path:topic>", methods=["POST"])
@auth.login_required
def get_id(topic: str):
    """Publish the message to the MQTT broker."""
    print(f"{topic=}")
    message = request.get_data()
    print(f"{message=}")
    if message:
        mqtt = mq.Client("restMQTT")
        if MQTT_USER and MQTT_PASS:
            mqtt.username_pw_set(MQTT_USER, MQTT_PASS)
        mqtt.connect(MQTT_HOST, MQTT_PORT, 15)
        mqtt.publish(topic, message)
        return "message send to the broker", 201
    return "no message", 400


def main():
    """Run the server."""
    serve(app, host="0.0.0.0", port=8080)
